# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableSearchSourceV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'condition_stats': 'list[ConditionTableStatInputForTableV1]',
        'properties_to_include': 'list[PropertiesForItemUUIDColumn]',
        'search_input': 'TableSearchInputV1'
    }

    attribute_map = {
        'condition_stats': 'conditionStats',
        'properties_to_include': 'propertiesToInclude',
        'search_input': 'searchInput'
    }

    def __init__(self, condition_stats=None, properties_to_include=None, search_input=None):
        """
        TableSearchSourceV1 - a model defined in Swagger
        """

        self._condition_stats = None
        self._properties_to_include = None
        self._search_input = None

        if condition_stats is not None:
          self.condition_stats = condition_stats
        if properties_to_include is not None:
          self.properties_to_include = properties_to_include
        if search_input is not None:
          self.search_input = search_input

    @property
    def condition_stats(self):
        """
        Gets the condition_stats of this TableSearchSourceV1.
        The list of statistics to calculate for the conditions/metrics

        :return: The condition_stats of this TableSearchSourceV1.
        :rtype: list[ConditionTableStatInputForTableV1]
        """
        return self._condition_stats

    @condition_stats.setter
    def condition_stats(self, condition_stats):
        """
        Sets the condition_stats of this TableSearchSourceV1.
        The list of statistics to calculate for the conditions/metrics

        :param condition_stats: The condition_stats of this TableSearchSourceV1.
        :type: list[ConditionTableStatInputForTableV1]
        """

        self._condition_stats = condition_stats

    @property
    def properties_to_include(self):
        """
        Gets the properties_to_include of this TableSearchSourceV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID 

        :return: The properties_to_include of this TableSearchSourceV1.
        :rtype: list[PropertiesForItemUUIDColumn]
        """
        return self._properties_to_include

    @properties_to_include.setter
    def properties_to_include(self, properties_to_include):
        """
        Sets the properties_to_include of this TableSearchSourceV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID 

        :param properties_to_include: The properties_to_include of this TableSearchSourceV1.
        :type: list[PropertiesForItemUUIDColumn]
        """

        self._properties_to_include = properties_to_include

    @property
    def search_input(self):
        """
        Gets the search_input of this TableSearchSourceV1.

        :return: The search_input of this TableSearchSourceV1.
        :rtype: TableSearchInputV1
        """
        return self._search_input

    @search_input.setter
    def search_input(self, search_input):
        """
        Sets the search_input of this TableSearchSourceV1.

        :param search_input: The search_input of this TableSearchSourceV1.
        :type: TableSearchInputV1
        """
        if search_input is None:
            raise ValueError("Invalid value for `search_input`, must not be `None`")

        self._search_input = search_input

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableSearchSourceV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
