# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionPreviewInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _bypass_model_controlled_restriction: Optional[bool]
    _column_definitions: ColumnDefinitionBulkEditInputListV1
    _rows: Optional[List[RowId]]


    def __init__(
        self,
        bypass_model_controlled_restriction: Optional[bool] = None,
        column_definitions: Optional[ColumnDefinitionBulkEditInputListV1] = None,
        rows: Optional[List[RowId]] = None,
    ) -> None: ...

    @property
    def bypass_model_controlled_restriction(self) -> Optional[bool]: ...

    @bypass_model_controlled_restriction.setter
    def bypass_model_controlled_restriction(self, bypass_model_controlled_restriction: Optional[bool]) -> None: ...

    @property
    def column_definitions(self) -> ColumnDefinitionBulkEditInputListV1: ...

    @column_definitions.setter
    def column_definitions(self, column_definitions: ColumnDefinitionBulkEditInputListV1) -> None: ...

    @property
    def rows(self) -> Optional[List[RowId]]: ...

    @rows.setter
    def rows(self, rows: Optional[List[RowId]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
