# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ConfigFieldV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _allow_null: bool
    _description: Optional[str]
    _name: Optional[str]
    _path: str
    _type: str
    _unique_key: str
    _value: Optional[Any]


    def __init__(
        self,
        allow_null: Optional[bool] = None,
        description: Optional[str] = None,
        name: Optional[str] = None,
        path: Optional[str] = None,
        type: Optional[str] = None,
        unique_key: Optional[str] = None,
        value: Optional[Any] = None,
    ) -> None: ...

    @property
    def allow_null(self) -> bool: ...

    @allow_null.setter
    def allow_null(self, allow_null: bool) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def name(self) -> Optional[str]: ...

    @name.setter
    def name(self, name: Optional[str]) -> None: ...

    @property
    def path(self) -> str: ...

    @path.setter
    def path(self, path: str) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def unique_key(self) -> str: ...

    @unique_key.setter
    def unique_key(self, unique_key: str) -> None: ...

    @property
    def value(self) -> Optional[Any]: ...

    @value.setter
    def value(self, value: Optional[Any]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
