# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class HierarchyOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'alias_column_id': 'str',
        'description': 'str',
        'effective_permissions': 'PermissionsV1',
        'filter_grouping': 'str',
        'id': 'str',
        'is_archived': 'bool',
        'is_redacted': 'bool',
        'name': 'str',
        'scoped_to': 'str',
        'status_message': 'str',
        'table_definition': 'ItemPreviewV1',
        'table_definition_output': 'TableDefinitionOutputV1',
        'translation_key': 'str',
        'type': 'str',
        'view_columns': 'list[ViewColumnOutputV1]'
    }

    attribute_map = {
        'alias_column_id': 'aliasColumnId',
        'description': 'description',
        'effective_permissions': 'effectivePermissions',
        'filter_grouping': 'filterGrouping',
        'id': 'id',
        'is_archived': 'isArchived',
        'is_redacted': 'isRedacted',
        'name': 'name',
        'scoped_to': 'scopedTo',
        'status_message': 'statusMessage',
        'table_definition': 'tableDefinition',
        'table_definition_output': 'tableDefinitionOutput',
        'translation_key': 'translationKey',
        'type': 'type',
        'view_columns': 'viewColumns'
    }

    def __init__(self, alias_column_id=None, description=None, effective_permissions=None, filter_grouping=None, id=None, is_archived=False, is_redacted=False, name=None, scoped_to=None, status_message=None, table_definition=None, table_definition_output=None, translation_key=None, type=None, view_columns=None):
        """
        HierarchyOutputV1 - a model defined in Swagger
        """

        self._alias_column_id = None
        self._description = None
        self._effective_permissions = None
        self._filter_grouping = None
        self._id = None
        self._is_archived = None
        self._is_redacted = None
        self._name = None
        self._scoped_to = None
        self._status_message = None
        self._table_definition = None
        self._table_definition_output = None
        self._translation_key = None
        self._type = None
        self._view_columns = None

        if alias_column_id is not None:
          self.alias_column_id = alias_column_id
        if description is not None:
          self.description = description
        if effective_permissions is not None:
          self.effective_permissions = effective_permissions
        if filter_grouping is not None:
          self.filter_grouping = filter_grouping
        if id is not None:
          self.id = id
        if is_archived is not None:
          self.is_archived = is_archived
        if is_redacted is not None:
          self.is_redacted = is_redacted
        if name is not None:
          self.name = name
        if scoped_to is not None:
          self.scoped_to = scoped_to
        if status_message is not None:
          self.status_message = status_message
        if table_definition is not None:
          self.table_definition = table_definition
        if table_definition_output is not None:
          self.table_definition_output = table_definition_output
        if translation_key is not None:
          self.translation_key = translation_key
        if type is not None:
          self.type = type
        if view_columns is not None:
          self.view_columns = view_columns

    @property
    def alias_column_id(self):
        """
        Gets the alias_column_id of this HierarchyOutputV1.
        The ID of the column the Hierarchy should use for aliases. If not provided item names will be used for the items in the hierarchy.

        :return: The alias_column_id of this HierarchyOutputV1.
        :rtype: str
        """
        return self._alias_column_id

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id):
        """
        Sets the alias_column_id of this HierarchyOutputV1.
        The ID of the column the Hierarchy should use for aliases. If not provided item names will be used for the items in the hierarchy.

        :param alias_column_id: The alias_column_id of this HierarchyOutputV1.
        :type: str
        """

        self._alias_column_id = alias_column_id

    @property
    def description(self):
        """
        Gets the description of this HierarchyOutputV1.
        Clarifying information or other plain language description of this item

        :return: The description of this HierarchyOutputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this HierarchyOutputV1.
        Clarifying information or other plain language description of this item

        :param description: The description of this HierarchyOutputV1.
        :type: str
        """

        self._description = description

    @property
    def effective_permissions(self):
        """
        Gets the effective_permissions of this HierarchyOutputV1.

        :return: The effective_permissions of this HierarchyOutputV1.
        :rtype: PermissionsV1
        """
        return self._effective_permissions

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions):
        """
        Sets the effective_permissions of this HierarchyOutputV1.

        :param effective_permissions: The effective_permissions of this HierarchyOutputV1.
        :type: PermissionsV1
        """

        self._effective_permissions = effective_permissions

    @property
    def filter_grouping(self):
        """
        Gets the filter_grouping of this HierarchyOutputV1.
        The logical filter grouping for column filters. Represents an expression on view column filter identifiers using AND/OR operators.  Parentheses may be present to dictate operation ordering. If filterGrouping is not present, all filters will be applied with the AND operator.

        :return: The filter_grouping of this HierarchyOutputV1.
        :rtype: str
        """
        return self._filter_grouping

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping):
        """
        Sets the filter_grouping of this HierarchyOutputV1.
        The logical filter grouping for column filters. Represents an expression on view column filter identifiers using AND/OR operators.  Parentheses may be present to dictate operation ordering. If filterGrouping is not present, all filters will be applied with the AND operator.

        :param filter_grouping: The filter_grouping of this HierarchyOutputV1.
        :type: str
        """

        self._filter_grouping = filter_grouping

    @property
    def id(self):
        """
        Gets the id of this HierarchyOutputV1.
        The ID that can be used to interact with the item

        :return: The id of this HierarchyOutputV1.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this HierarchyOutputV1.
        The ID that can be used to interact with the item

        :param id: The id of this HierarchyOutputV1.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this HierarchyOutputV1.
        Whether item is archived

        :return: The is_archived of this HierarchyOutputV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this HierarchyOutputV1.
        Whether item is archived

        :param is_archived: The is_archived of this HierarchyOutputV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def is_redacted(self):
        """
        Gets the is_redacted of this HierarchyOutputV1.
        Whether item is redacted

        :return: The is_redacted of this HierarchyOutputV1.
        :rtype: bool
        """
        return self._is_redacted

    @is_redacted.setter
    def is_redacted(self, is_redacted):
        """
        Sets the is_redacted of this HierarchyOutputV1.
        Whether item is redacted

        :param is_redacted: The is_redacted of this HierarchyOutputV1.
        :type: bool
        """

        self._is_redacted = is_redacted

    @property
    def name(self):
        """
        Gets the name of this HierarchyOutputV1.
        The human readable name

        :return: The name of this HierarchyOutputV1.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HierarchyOutputV1.
        The human readable name

        :param name: The name of this HierarchyOutputV1.
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")

        self._name = name

    @property
    def scoped_to(self):
        """
        Gets the scoped_to of this HierarchyOutputV1.
        The ID of the workbook to which the hierarchy is scoped. If not present, the hierarchy is globally scoped

        :return: The scoped_to of this HierarchyOutputV1.
        :rtype: str
        """
        return self._scoped_to

    @scoped_to.setter
    def scoped_to(self, scoped_to):
        """
        Sets the scoped_to of this HierarchyOutputV1.
        The ID of the workbook to which the hierarchy is scoped. If not present, the hierarchy is globally scoped

        :param scoped_to: The scoped_to of this HierarchyOutputV1.
        :type: str
        """

        self._scoped_to = scoped_to

    @property
    def status_message(self):
        """
        Gets the status_message of this HierarchyOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :return: The status_message of this HierarchyOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this HierarchyOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation

        :param status_message: The status_message of this HierarchyOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def table_definition(self):
        """
        Gets the table_definition of this HierarchyOutputV1.

        :return: The table_definition of this HierarchyOutputV1.
        :rtype: ItemPreviewV1
        """
        return self._table_definition

    @table_definition.setter
    def table_definition(self, table_definition):
        """
        Sets the table_definition of this HierarchyOutputV1.

        :param table_definition: The table_definition of this HierarchyOutputV1.
        :type: ItemPreviewV1
        """
        if table_definition is None:
            raise ValueError("Invalid value for `table_definition`, must not be `None`")

        self._table_definition = table_definition

    @property
    def table_definition_output(self):
        """
        Gets the table_definition_output of this HierarchyOutputV1.

        :return: The table_definition_output of this HierarchyOutputV1.
        :rtype: TableDefinitionOutputV1
        """
        return self._table_definition_output

    @table_definition_output.setter
    def table_definition_output(self, table_definition_output):
        """
        Sets the table_definition_output of this HierarchyOutputV1.

        :param table_definition_output: The table_definition_output of this HierarchyOutputV1.
        :type: TableDefinitionOutputV1
        """
        if table_definition_output is None:
            raise ValueError("Invalid value for `table_definition_output`, must not be `None`")

        self._table_definition_output = table_definition_output

    @property
    def translation_key(self):
        """
        Gets the translation_key of this HierarchyOutputV1.
        The item's translation key, if any

        :return: The translation_key of this HierarchyOutputV1.
        :rtype: str
        """
        return self._translation_key

    @translation_key.setter
    def translation_key(self, translation_key):
        """
        Sets the translation_key of this HierarchyOutputV1.
        The item's translation key, if any

        :param translation_key: The translation_key of this HierarchyOutputV1.
        :type: str
        """

        self._translation_key = translation_key

    @property
    def type(self):
        """
        Gets the type of this HierarchyOutputV1.
        The type of the item

        :return: The type of this HierarchyOutputV1.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this HierarchyOutputV1.
        The type of the item

        :param type: The type of this HierarchyOutputV1.
        :type: str
        """
        if type is None:
            raise ValueError("Invalid value for `type`, must not be `None`")

        self._type = type

    @property
    def view_columns(self):
        """
        Gets the view_columns of this HierarchyOutputV1.
        View Columns for the Table that correspond to Column Definitions. They contain grouping, filtering and sorting information for a given Hierarchy view applied to an Item Table.

        :return: The view_columns of this HierarchyOutputV1.
        :rtype: list[ViewColumnOutputV1]
        """
        return self._view_columns

    @view_columns.setter
    def view_columns(self, view_columns):
        """
        Sets the view_columns of this HierarchyOutputV1.
        View Columns for the Table that correspond to Column Definitions. They contain grouping, filtering and sorting information for a given Hierarchy view applied to an Item Table.

        :param view_columns: The view_columns of this HierarchyOutputV1.
        :type: list[ViewColumnOutputV1]
        """
        if view_columns is None:
            raise ValueError("Invalid value for `view_columns`, must not be `None`")

        self._view_columns = view_columns

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, HierarchyOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
