# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class SimpleTableInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'columns_to_include': 'list[str]',
        'include_ancestors': 'bool',
        'limit': 'int',
        'properties_to_include': 'list[PropertiesForItemUUIDColumn]',
        'search_input': 'TableSearchInputV1',
        'table_formulas': 'list[TableFormula]'
    }

    attribute_map = {
        'columns_to_include': 'columnsToInclude',
        'include_ancestors': 'includeAncestors',
        'limit': 'limit',
        'properties_to_include': 'propertiesToInclude',
        'search_input': 'searchInput',
        'table_formulas': 'tableFormulas'
    }

    def __init__(self, columns_to_include=None, include_ancestors=None, limit=None, properties_to_include=None, search_input=None, table_formulas=None):
        """
        SimpleTableInputV1 - a model defined in Swagger
        """

        self._columns_to_include = None
        self._include_ancestors = None
        self._limit = None
        self._properties_to_include = None
        self._search_input = None
        self._table_formulas = None

        if columns_to_include is not None:
          self.columns_to_include = columns_to_include
        if include_ancestors is not None:
          self.include_ancestors = include_ancestors
        if limit is not None:
          self.limit = limit
        if properties_to_include is not None:
          self.properties_to_include = properties_to_include
        if search_input is not None:
          self.search_input = search_input
        if table_formulas is not None:
          self.table_formulas = table_formulas

    @property
    def columns_to_include(self):
        """
        Gets the columns_to_include of this SimpleTableInputV1.
        What columns to include in the result. If set to null or not provided, all columns are returned. To include context columns, prepend the column with either 'context_comments.', 'context_label.', or 'context_opaque.' Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :return: The columns_to_include of this SimpleTableInputV1.
        :rtype: list[str]
        """
        return self._columns_to_include

    @columns_to_include.setter
    def columns_to_include(self, columns_to_include):
        """
        Sets the columns_to_include of this SimpleTableInputV1.
        What columns to include in the result. If set to null or not provided, all columns are returned. To include context columns, prepend the column with either 'context_comments.', 'context_label.', or 'context_opaque.' Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :param columns_to_include: The columns_to_include of this SimpleTableInputV1.
        :type: list[str]
        """

        self._columns_to_include = columns_to_include

    @property
    def include_ancestors(self):
        """
        Gets the include_ancestors of this SimpleTableInputV1.
        Boolean for if search ancestor columns should be generated and returned

        :return: The include_ancestors of this SimpleTableInputV1.
        :rtype: bool
        """
        return self._include_ancestors

    @include_ancestors.setter
    def include_ancestors(self, include_ancestors):
        """
        Sets the include_ancestors of this SimpleTableInputV1.
        Boolean for if search ancestor columns should be generated and returned

        :param include_ancestors: The include_ancestors of this SimpleTableInputV1.
        :type: bool
        """

        self._include_ancestors = include_ancestors

    @property
    def limit(self):
        """
        Gets the limit of this SimpleTableInputV1.
        Maximum number of rows to return

        :return: The limit of this SimpleTableInputV1.
        :rtype: int
        """
        return self._limit

    @limit.setter
    def limit(self, limit):
        """
        Sets the limit of this SimpleTableInputV1.
        Maximum number of rows to return

        :param limit: The limit of this SimpleTableInputV1.
        :type: int
        """
        if limit is None:
            raise ValueError("Invalid value for `limit`, must not be `None`")

        self._limit = limit

    @property
    def properties_to_include(self):
        """
        Gets the properties_to_include of this SimpleTableInputV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID  Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :return: The properties_to_include of this SimpleTableInputV1.
        :rtype: list[PropertiesForItemUUIDColumn]
        """
        return self._properties_to_include

    @properties_to_include.setter
    def properties_to_include(self, properties_to_include):
        """
        Sets the properties_to_include of this SimpleTableInputV1.
        Additional properties to fetch per row that will be added as additional columns. The following columns can be used:  item id,  Asset,  Path,  Value UOM,  Datasource,  Source Column ID  Ancestor level columns should not be included, use the includeAncestors boolean to include those if desired.

        :param properties_to_include: The properties_to_include of this SimpleTableInputV1.
        :type: list[PropertiesForItemUUIDColumn]
        """

        self._properties_to_include = properties_to_include

    @property
    def search_input(self):
        """
        Gets the search_input of this SimpleTableInputV1.

        :return: The search_input of this SimpleTableInputV1.
        :rtype: TableSearchInputV1
        """
        return self._search_input

    @search_input.setter
    def search_input(self, search_input):
        """
        Sets the search_input of this SimpleTableInputV1.

        :param search_input: The search_input of this SimpleTableInputV1.
        :type: TableSearchInputV1
        """
        if search_input is None:
            raise ValueError("Invalid value for `search_input`, must not be `None`")

        self._search_input = search_input

    @property
    def table_formulas(self):
        """
        Gets the table_formulas of this SimpleTableInputV1.
        The formulas to run against the items in the table results. Each formula result will be returned as their own column in the order requested by the formula. ColumnsToInclude must include the column containing the items to run the formula across.

        :return: The table_formulas of this SimpleTableInputV1.
        :rtype: list[TableFormula]
        """
        return self._table_formulas

    @table_formulas.setter
    def table_formulas(self, table_formulas):
        """
        Sets the table_formulas of this SimpleTableInputV1.
        The formulas to run against the items in the table results. Each formula result will be returned as their own column in the order requested by the formula. ColumnsToInclude must include the column containing the items to run the formula across.

        :param table_formulas: The table_formulas of this SimpleTableInputV1.
        :type: list[TableFormula]
        """

        self._table_formulas = table_formulas

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, SimpleTableInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
