# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ScheduledNotebookResultInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _error: Optional[str]
    _run_started_at: str
    _run_time: Optional[int]
    _warning: Optional[str]


    def __init__(
        self,
        error: Optional[str] = None,
        run_started_at: Optional[str] = None,
        run_time: Optional[int] = None,
        warning: Optional[str] = None,
    ) -> None: ...

    @property
    def error(self) -> Optional[str]: ...

    @error.setter
    def error(self, error: Optional[str]) -> None: ...

    @property
    def run_started_at(self) -> str: ...

    @run_started_at.setter
    def run_started_at(self, run_started_at: str) -> None: ...

    @property
    def run_time(self) -> Optional[int]: ...

    @run_time.setter
    def run_time(self, run_time: Optional[int]) -> None: ...

    @property
    def warning(self) -> Optional[str]: ...

    @warning.setter
    def warning(self, warning: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
