# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AddOnInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _add_on_components: Optional[str]
    _add_on_identifier: str
    _description: Optional[str]
    _enabled: Optional[bool]
    _in_development: Optional[bool]
    _name: str
    _version_string: Optional[str]


    def __init__(
        self,
        add_on_components: Optional[str] = None,
        add_on_identifier: Optional[str] = None,
        description: Optional[str] = None,
        enabled: Optional[bool] = True,
        in_development: Optional[bool] = False,
        name: Optional[str] = None,
        version_string: Optional[str] = None,
    ) -> None: ...

    @property
    def add_on_components(self) -> Optional[str]: ...

    @add_on_components.setter
    def add_on_components(self, add_on_components: Optional[str]) -> None: ...

    @property
    def add_on_identifier(self) -> str: ...

    @add_on_identifier.setter
    def add_on_identifier(self, add_on_identifier: str) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def enabled(self) -> Optional[bool]: ...

    @enabled.setter
    def enabled(self, enabled: Optional[bool]) -> None: ...

    @property
    def in_development(self) -> Optional[bool]: ...

    @in_development.setter
    def in_development(self, in_development: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def version_string(self) -> Optional[str]: ...

    @version_string.setter
    def version_string(self, version_string: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
