# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ConfigurationOptionInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'note': 'str',
        'path': 'str',
        'value': 'object'
    }

    attribute_map = {
        'note': 'note',
        'path': 'path',
        'value': 'value'
    }

    def __init__(self, note=None, path=None, value=None):
        """
        ConfigurationOptionInputV1 - a model defined in Swagger
        """

        self._note = None
        self._path = None
        self._value = None

        if note is not None:
          self.note = note
        if path is not None:
          self.path = path
        if value is not None:
          self.value = value

    @property
    def note(self):
        """
        Gets the note of this ConfigurationOptionInputV1.
        A plain text note to provide context on the configuration change.

        :return: The note of this ConfigurationOptionInputV1.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """
        Sets the note of this ConfigurationOptionInputV1.
        A plain text note to provide context on the configuration change.

        :param note: The note of this ConfigurationOptionInputV1.
        :type: str
        """

        self._note = note

    @property
    def path(self):
        """
        Gets the path of this ConfigurationOptionInputV1.
        The unique identifier of the configuration option. Slashes in the path imply a hierarchy.

        :return: The path of this ConfigurationOptionInputV1.
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """
        Sets the path of this ConfigurationOptionInputV1.
        The unique identifier of the configuration option. Slashes in the path imply a hierarchy.

        :param path: The path of this ConfigurationOptionInputV1.
        :type: str
        """
        if path is None:
            raise ValueError("Invalid value for `path`, must not be `None`")

        self._path = path

    @property
    def value(self):
        """
        Gets the value of this ConfigurationOptionInputV1.
        The new value to set for this option. If omitted, the default value will be used.

        :return: The value of this ConfigurationOptionInputV1.
        :rtype: object
        """
        return self._value

    @value.setter
    def value(self, value):
        """
        Sets the value of this ConfigurationOptionInputV1.
        The new value to set for this option. If omitted, the default value will be used.

        :param value: The value of this ConfigurationOptionInputV1.
        :type: object
        """

        self._value = value

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ConfigurationOptionInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
