# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MediaType(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _parameters: Optional[Dict[str, str]]
    _subtype: Optional[str]
    _type: Optional[str]
    _wildcard_subtype: Optional[bool]
    _wildcard_type: Optional[bool]


    def __init__(
        self,
        parameters: Optional[Dict[str, str]] = None,
        subtype: Optional[str] = None,
        type: Optional[str] = None,
        wildcard_subtype: Optional[bool] = None,
        wildcard_type: Optional[bool] = None,
    ) -> None: ...

    @property
    def parameters(self) -> Optional[Dict[str, str]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[Dict[str, str]]) -> None: ...

    @property
    def subtype(self) -> Optional[str]: ...

    @subtype.setter
    def subtype(self, subtype: Optional[str]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    @property
    def wildcard_subtype(self) -> Optional[bool]: ...

    @wildcard_subtype.setter
    def wildcard_subtype(self, wildcard_subtype: Optional[bool]) -> None: ...

    @property
    def wildcard_type(self) -> Optional[bool]: ...

    @wildcard_type.setter
    def wildcard_type(self, wildcard_type: Optional[bool]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
