# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CustomAgentSummaryOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: str
    _draft: CustomAgentDraftInfoOutputV1
    _effective_permissions: Optional[PermissionsV1]
    _id: str
    _name: str
    _owner: Optional[bool]
    _updated_at: str


    def __init__(
        self,
        created_at: Optional[str] = None,
        draft: Optional[CustomAgentDraftInfoOutputV1] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        id: Optional[str] = None,
        name: Optional[str] = None,
        owner: Optional[bool] = None,
        updated_at: Optional[str] = None,
    ) -> None: ...

    @property
    def created_at(self) -> str: ...

    @created_at.setter
    def created_at(self, created_at: str) -> None: ...

    @property
    def draft(self) -> CustomAgentDraftInfoOutputV1: ...

    @draft.setter
    def draft(self, draft: CustomAgentDraftInfoOutputV1) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def owner(self) -> Optional[bool]: ...

    @owner.setter
    def owner(self, owner: Optional[bool]) -> None: ...

    @property
    def updated_at(self) -> str: ...

    @updated_at.setter
    def updated_at(self, updated_at: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
