# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ContextPermissionDeniedOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'error_code': 'str',
        'item_id': 'str',
        'permission_type': 'str',
        'status_message': 'str',
        'table_id': 'str'
    }

    attribute_map = {
        'error_code': 'errorCode',
        'item_id': 'itemId',
        'permission_type': 'permissionType',
        'status_message': 'statusMessage',
        'table_id': 'tableId'
    }

    def __init__(self, error_code=None, item_id=None, permission_type=None, status_message=None, table_id=None):
        """
        ContextPermissionDeniedOutputV1 - a model defined in Swagger
        """

        self._error_code = None
        self._item_id = None
        self._permission_type = None
        self._status_message = None
        self._table_id = None

        if error_code is not None:
          self.error_code = error_code
        if item_id is not None:
          self.item_id = item_id
        if permission_type is not None:
          self.permission_type = permission_type
        if status_message is not None:
          self.status_message = status_message
        if table_id is not None:
          self.table_id = table_id

    @property
    def error_code(self):
        """
        Gets the error_code of this ContextPermissionDeniedOutputV1.
        Stable error code for context permission failures

        :return: The error_code of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._error_code

    @error_code.setter
    def error_code(self, error_code):
        """
        Sets the error_code of this ContextPermissionDeniedOutputV1.
        Stable error code for context permission failures

        :param error_code: The error_code of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._error_code = error_code

    @property
    def item_id(self):
        """
        Gets the item_id of this ContextPermissionDeniedOutputV1.
        The item that the user did not have permission to access

        :return: The item_id of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._item_id

    @item_id.setter
    def item_id(self, item_id):
        """
        Sets the item_id of this ContextPermissionDeniedOutputV1.
        The item that the user did not have permission to access

        :param item_id: The item_id of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._item_id = item_id

    @property
    def permission_type(self):
        """
        Gets the permission_type of this ContextPermissionDeniedOutputV1.
        The permission that was required to complete the request

        :return: The permission_type of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._permission_type

    @permission_type.setter
    def permission_type(self, permission_type):
        """
        Sets the permission_type of this ContextPermissionDeniedOutputV1.
        The permission that was required to complete the request

        :param permission_type: The permission_type of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._permission_type = permission_type

    @property
    def status_message(self):
        """
        Gets the status_message of this ContextPermissionDeniedOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :return: The status_message of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._status_message

    @status_message.setter
    def status_message(self, status_message):
        """
        Sets the status_message of this ContextPermissionDeniedOutputV1.
        A plain language status message with information about any issues that may have been encountered during an operation. Null if the status message has not been set.

        :param status_message: The status_message of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._status_message = status_message

    @property
    def table_id(self):
        """
        Gets the table_id of this ContextPermissionDeniedOutputV1.
        The table that also required permissions, when applicable

        :return: The table_id of this ContextPermissionDeniedOutputV1.
        :rtype: str
        """
        return self._table_id

    @table_id.setter
    def table_id(self, table_id):
        """
        Sets the table_id of this ContextPermissionDeniedOutputV1.
        The table that also required permissions, when applicable

        :param table_id: The table_id of this ContextPermissionDeniedOutputV1.
        :type: str
        """

        self._table_id = table_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ContextPermissionDeniedOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
