# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class HierarchyInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _alias_column_id: Optional[str]
    _description: Optional[str]
    _filter_grouping: Optional[str]
    _name: str
    _scoped_to: Optional[str]
    _table_definition_id: Optional[str]
    _view_columns: List[ViewColumnInputV1]


    def __init__(
        self,
        alias_column_id: Optional[str] = None,
        description: Optional[str] = None,
        filter_grouping: Optional[str] = None,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        table_definition_id: Optional[str] = None,
        view_columns: Optional[List[ViewColumnInputV1]] = None,
    ) -> None: ...

    @property
    def alias_column_id(self) -> Optional[str]: ...

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def filter_grouping(self) -> Optional[str]: ...

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping: Optional[str]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def table_definition_id(self) -> Optional[str]: ...

    @table_definition_id.setter
    def table_definition_id(self, table_definition_id: Optional[str]) -> None: ...

    @property
    def view_columns(self) -> List[ViewColumnInputV1]: ...

    @view_columns.setter
    def view_columns(self, view_columns: List[ViewColumnInputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
