# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class PropertiesForItemUUIDColumn(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'property_names': 'list[str]',
        'uuid_column': 'str'
    }

    attribute_map = {
        'property_names': 'propertyNames',
        'uuid_column': 'uuidColumn'
    }

    def __init__(self, property_names=None, uuid_column=None):
        """
        PropertiesForItemUUIDColumn - a model defined in Swagger
        """

        self._property_names = None
        self._uuid_column = None

        if property_names is not None:
          self.property_names = property_names
        if uuid_column is not None:
          self.uuid_column = uuid_column

    @property
    def property_names(self):
        """
        Gets the property_names of this PropertiesForItemUUIDColumn.
        The name of the property to return for the item

        :return: The property_names of this PropertiesForItemUUIDColumn.
        :rtype: list[str]
        """
        return self._property_names

    @property_names.setter
    def property_names(self, property_names):
        """
        Sets the property_names of this PropertiesForItemUUIDColumn.
        The name of the property to return for the item

        :param property_names: The property_names of this PropertiesForItemUUIDColumn.
        :type: list[str]
        """

        self._property_names = property_names

    @property
    def uuid_column(self):
        """
        Gets the uuid_column of this PropertiesForItemUUIDColumn.
        The name of the UUID column whose item property should be returned

        :return: The uuid_column of this PropertiesForItemUUIDColumn.
        :rtype: str
        """
        return self._uuid_column

    @uuid_column.setter
    def uuid_column(self, uuid_column):
        """
        Sets the uuid_column of this PropertiesForItemUUIDColumn.
        The name of the UUID column whose item property should be returned

        :param uuid_column: The uuid_column of this PropertiesForItemUUIDColumn.
        :type: str
        """

        self._uuid_column = uuid_column

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PropertiesForItemUUIDColumn):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
