# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AssetGroupTreeOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _children: Optional[List[AssetGroupTreeOutputV1]]
    _datasource_id: Optional[str]
    _description: Optional[str]
    _item: Optional[ItemPreviewWithAssetsV1]
    _parameters: Optional[List[FormulaParameterOutputV1]]


    def __init__(
        self,
        children: Optional[List[AssetGroupTreeOutputV1]] = None,
        datasource_id: Optional[str] = None,
        description: Optional[str] = None,
        item: Optional[ItemPreviewWithAssetsV1] = None,
        parameters: Optional[List[FormulaParameterOutputV1]] = None,
    ) -> None: ...

    @property
    def children(self) -> Optional[List[AssetGroupTreeOutputV1]]: ...

    @children.setter
    def children(self, children: Optional[List[AssetGroupTreeOutputV1]]) -> None: ...

    @property
    def datasource_id(self) -> Optional[str]: ...

    @datasource_id.setter
    def datasource_id(self, datasource_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def item(self) -> Optional[ItemPreviewWithAssetsV1]: ...

    @item.setter
    def item(self, item: Optional[ItemPreviewWithAssetsV1]) -> None: ...

    @property
    def parameters(self) -> Optional[List[FormulaParameterOutputV1]]: ...

    @parameters.setter
    def parameters(self, parameters: Optional[List[FormulaParameterOutputV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
