# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.123.2-v202604030243-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class FormulaErrorOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column: Optional[int]
    _error_category: Optional[str]
    _error_type: Optional[str]
    _line: Optional[int]
    _message: Optional[str]
    _status_message: Optional[str]


    def __init__(
        self,
        column: Optional[int] = None,
        error_category: Optional[str] = None,
        error_type: Optional[str] = None,
        line: Optional[int] = None,
        message: Optional[str] = None,
        status_message: Optional[str] = None,
    ) -> None: ...

    @property
    def column(self) -> Optional[int]: ...

    @column.setter
    def column(self, column: Optional[int]) -> None: ...

    @property
    def error_category(self) -> Optional[str]: ...

    @error_category.setter
    def error_category(self, error_category: Optional[str]) -> None: ...

    @property
    def error_type(self) -> Optional[str]: ...

    @error_type.setter
    def error_type(self, error_type: Optional[str]) -> None: ...

    @property
    def line(self) -> Optional[int]: ...

    @line.setter
    def line(self, line: Optional[int]) -> None: ...

    @property
    def message(self) -> Optional[str]: ...

    @message.setter
    def message(self, message: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
